pub struct TrackingInformation {
pub tracking_id: String,
pub summary: Box<TrackingSummary>,
pub promised_delivery_date: String,
pub event_history: Vec<Event>,
}Expand description
TrackingInformation : The payload schema for the getTrackingInformation operation.
Fields
tracking_id: StringThe tracking id generated to each shipment. It contains a series of letters or digits or both.
summary: Box<TrackingSummary>promised_delivery_date: StringThe promised delivery date and time of a shipment.
event_history: Vec<Event>A list of events of a shipment.
Implementations
sourceimpl TrackingInformation
impl TrackingInformation
sourcepub fn new(
tracking_id: String,
summary: TrackingSummary,
promised_delivery_date: String,
event_history: Vec<Event>
) -> TrackingInformation
pub fn new(
tracking_id: String,
summary: TrackingSummary,
promised_delivery_date: String,
event_history: Vec<Event>
) -> TrackingInformation
The payload schema for the getTrackingInformation operation.